==> alma_client-0.2.0-py3-none-any.whl: alma_client/v1/common.py <==
import datetime

from typing import Optional, List

from pydantic import BaseModel, validator

DATE_FORMAT = "%Y-%m-%dZ"
DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"


def parse_date(value: str) -> datetime.date:
    """Parse timestamp on format like 2011-09-10Z"""
    parsed_datetime = datetime.datetime.strptime(value, DATE_FORMAT)
    return parsed_datetime.date()


def parse_datetime(value: str) -> datetime.datetime:
    """Parse timestamp on format like 2021-06-14T12:09:47.555Z"""
    parsed_datetime = datetime.datetime.strptime(value, DATETIME_FORMAT)
    return parsed_datetime.replace(tzinfo=datetime.timezone.utc)


def serialize_date(value: datetime.date) -> str:
    """Serialize date to format like 2011-09-10Z"""
    return value.strftime(DATE_FORMAT)


def serialize_datetime(value: datetime.datetime) -> str:
    """Serialize datetime to format like 2021-06-14T12:09:47.555Z"""
    return value.strftime(DATETIME_FORMAT)


ENCODERS_BY_TYPE = {datetime.date: serialize_date,
                    datetime.datetime: serialize_datetime}


class AlmaModel(BaseModel):
    def json_bytes(self, *args, exclude_unset=True, encode="utf-8", **kwargs):
        """Get json as bytes string

        Useful for doing PUT / update:
        >>>c = alma_client.courses.get("12655837450002204")
        >>>c.name = "new_name"
        >>>c_new = alma_client.courses.update("12655837450002204", data=c.json_bytes())

        """
        json_obj = self.json(*args, exclude_unset=exclude_unset, **kwargs)
        return json_obj.encode(encode)

    # Be very careful when defining new Config for subclasses. The Config of the
    # subclass needs to inherit from this Config!
    class Config:
        json_encoders = ENCODERS_BY_TYPE


class DescribedValue(AlmaModel):
    value: str
    desc: str


class OptionalDescribedValue(AlmaModel):
    value: Optional[str]
    desc: Optional[str]


class SearchWrapper(AlmaModel):
    total_record_count: int

    @validator("total_record_count", pre=True)
    def get_record_count(cls, value):
        if value is None:
            return 0
        return value

    def get_results(self) -> Optional[List[AlmaModel]]:
        """Return results on the current page"""
        raise NotImplementedError

==> alma_client-0.3.0-py3-none-any.whl: alma_client/v1/common.py <==
import datetime

from typing import Optional, List

from pydantic import BaseModel, validator

DATE_FORMAT = "%Y-%m-%dZ"
DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S.%fZ"


def parse_date(value: str) -> datetime.date:
    """Parse timestamp on format like 2011-09-10Z"""
    parsed_datetime = datetime.datetime.strptime(value, DATE_FORMAT)
    return parsed_datetime.date()


def parse_datetime(value: str) -> datetime.datetime:
    """Parse timestamp on format like 2021-06-14T12:09:47.555Z"""
    parsed_datetime = datetime.datetime.strptime(value, DATETIME_FORMAT)
    return parsed_datetime.replace(tzinfo=datetime.timezone.utc)


def serialize_date(value: datetime.date) -> str:
    """Serialize date to format like 2011-09-10Z"""
    return value.strftime(DATE_FORMAT)


def serialize_datetime(value: datetime.datetime) -> str:
    """Serialize datetime to format like 2021-06-14T12:09:47.555Z"""
    return value.strftime(DATETIME_FORMAT)


ENCODERS_BY_TYPE = {
    datetime.date: serialize_date,
    datetime.datetime: serialize_datetime,
}


class AlmaModel(BaseModel):
    def json_bytes(self, *args, exclude_unset=True, encode="utf-8", **kwargs):
        """Get json as bytes string

        Useful for doing PUT / update:
        >>>c = alma_client.courses.get("12655837450002204")
        >>>c.name = "new_name"
        >>>c_new = alma_client.courses.update("12655837450002204", data=c.json_bytes())

        """
        json_obj = self.json(*args, exclude_unset=exclude_unset, **kwargs)
        return json_obj.encode(encode)

    # Be very careful when defining new Config for subclasses. The Config of the
    # subclass needs to inherit from this Config!
    class Config:
        json_encoders = ENCODERS_BY_TYPE


class DescribedValue(AlmaModel):
    value: str
    desc: str


class OptionalDescribedValue(AlmaModel):
    value: Optional[str]
    desc: Optional[str]


class SearchWrapper(AlmaModel):
    total_record_count: int

    @validator("total_record_count", pre=True)
    def get_record_count(cls, value):
        if value is None:
            return 0
        return value

    def get_results(self) -> Optional[List[AlmaModel]]:
        """Return results on the current page"""
        raise NotImplementedError
